@@ -1,5 +1,5 @@
 quicr <- function(data, lambda) {
-    S    <- cov(data)
+    S    <- cor(data)
     est  <- QUIC::QUIC(S, rho=1, path=lambda, msg=0, tol=1e-2)
     path <-  lapply(seq(length(lambda)), function(i) {
                 tmp <- est$X[,,i]; diag(tmp) <- 0
@@ -13,11 +13,11 @@ quicr <- function(data, lambda) {
 runtests <- function(pfun, pclass, dat, fun, fargs, ...) {
     G <- dat$theta
     test_that("bad crits results in right errors", {
-        lams <- getLamPath(.7, .1, 5)
+        lams <- getLamPath(.7, .5, 5)
         hargs <- c(fargs, list(lambda=lams))
-        expect_error(out <- pfun(dat$data, fun=fun, fargs=hargs, rep.num=2, criterion=c("stars", "foo"),
-                       ...), "foo")
-        expect_error(out <- pfun(dat$data, fun=fun, fargs=hargs, rep.num=2, 
+        expect_error(out <- pfun(dat$data, fun=fun, fargs=hargs, rep.num=2,
+           criterion=c("stars", "foo"), ...), "foo")
+        expect_error(out <- pfun(dat$data, fun=fun, fargs=hargs, rep.num=2,
                        criterion=c("estrada", "sufficiency")))
     })
 
@@ -27,20 +27,21 @@ runtests <- function(pfun, pclass, dat, fun, fargs, ...) {
         hargs <- c(fargs, list(lambda=lams))
         expect_warning(out <- pfun(dat$data, fun=fun, fargs=hargs, rep.num=2,
                        ...), "lambda path")
-        expect_warning(out <- pfun(dat$data, fun=fun, fargs=c(list(lambda=lams[1]), fargs), rep.num=2,
-                       ...),"1 value")
-        expect_error(out <- pfun(dat$data, fun=fun, fargs=c(list(lams=lams), fargs), rep.num=2), "missing")
-        expect_warning(out <- pfun(dat$data, fun=fun, fargs=c(list(lambda=lams[c(5,4)]), fargs), rep.num=2,
-                       ...), "supplied values")
+        expect_warning(out <- pfun(dat$data, fun=fun,
+              fargs=c(list(lambda=lams[1]), fargs), rep.num=2, ...),"1 value")
+        expect_error(out <- pfun(dat$data, fun=fun, fargs=c(list(lams=lams),
+                fargs), rep.num=2), "missing")
+        expect_warning(out <- pfun(dat$data, fun=fun,
+              fargs=c(list(lambda=lams[c(5,4)]), fargs), rep.num=2, ...),
+               "supplied values")
     })
 
-    mlam <- signif(getMaxCov(dat$sigmahat)+.1, 3)
-    lams  <- getLamPath(mlam, .05, 15)
+    mlam  <- getMaxCov(scale(dat$data))
+    lams  <- getLamPath(mlam, 5e-3, 35)
     hargs <- c(fargs, list(lambda=lams))
-    out   <- pfun(dat$data, fun=fun, fargs=hargs, criterion=c("stars"), rep.num=4, ...)
+    out   <- pfun(dat$data, fun=fun, fargs=hargs, criterion="stars", rep.num=6, ...)
     outb  <- update(out, lb.stars=TRUE, ub.stars=TRUE, criterion=c("stars", "gcd"))
 
-
     test_that("pulsar w/ lambda path works for fun", {
         ## run pulsar in serial mode
         expect_is(out, pclass)
@@ -51,8 +52,6 @@ runtests <- function(pfun, pclass, dat, fun, fargs, ...) {
         expect_true(all(sapply(out$stars$merge, function(x) all(dim(x) == dim(G)))))
         expect_true(all(sapply(out$stars$merge, function(x) all(dim(x) == ncol(dat$data)))))
 
-        ## run with gcd
-##        out <- pfun(dat$data, fun=fun, fargs=hargs, criterion=c("stars", "gcd"), rep.num=2, ...)
     })
 
     test_that("pulsar bounds are consistent", {
@@ -60,7 +59,10 @@ runtests <- function(pfun, pclass, dat, fun, fargs, ...) {
 ##        expect_equal(length(out$gcd$summary), length(out$stars$summary))
         expect_equal(outb$gcd$criterion, "graphlet.stability")
         expect_error(fit <- refit(out, 'stars'), NA)
-        expect_equal(outb$stars$opt.ind, out$stars$opt.ind) # same answer using bounds
+
+       # same answer using bounds
+        expect_equal(outb$stars$opt.ind, out$stars$opt.ind)
+
         ## gcd computed between bounds
         expect_equal(length(outb$gcd$summary), outb$stars$lb.index-outb$stars$ub.index+1)
         expect_equal(opt.index(outb, 'stars'), opt.index(out, 'stars')) # same answer using bounds
@@ -74,6 +76,13 @@ runtests <- function(pfun, pclass, dat, fun, fargs, ...) {
         expect_gte(gcdF1, starsF1)
     })
     return(list(out=out, outb=outb))
+
+    test_that("calling environments are stored correct", {
+      ## test that est parent.frame is current environment
+      expect_equal(getEnvir(out), environment())
+      expect_equal(getEnvir(outb), environment())
+    })
+
 }
 
 
